@@ -69,13 +69,7 @@ static void hexRaw(const void* buffer, size_t size)
     }
 }
 
-void hexDisp(const void* buffer, size_t size)
-{
-    hexRaw(buffer, size);
-    printf("\n");
-}
-
-static void printHash(const void* table, size_t n, Htype_e htype)
+void printHash(const void* table, size_t n, Htype_e htype)
 {
     if ((htype == ht64) || (htype == ht32)){
         uint64_t const h64 = ((const uint64_t*)table)[n];
@@ -112,7 +106,7 @@ static uint64_t avalanche64(uint64_t h64)
     return h64;
 }
 
-static unsigned char randomByte(size_t n)
+static unsigned char randomByte(uint64_t n)
 {
     uint64_t n64 = avalanche64(n+1);
     n64 *= prime64_1;
@@ -246,7 +240,7 @@ typedef struct {
     /* slab5 */
     size_t nbSlabs;
     size_t current;
-    size_t prngSeed;
+    uint64_t prngSeed;
 } sampleFactory;
 
 static void init_sampleFactory(sampleFactory* sf, uint64_t htotal)
@@ -288,7 +282,7 @@ static void free_sampleFactory(sampleFactory* sf)
 
 static void flipbit(void* buffer, uint64_t bitID)
 {
-    size_t const pos = bitID >> 3;
+    size_t const pos = (size_t)(bitID >> 3);
     unsigned char const mask = (unsigned char)(1 << (bitID & 7));
     unsigned char* const p = (unsigned char*)buffer;
     p[pos] ^= mask;
@@ -422,7 +416,7 @@ static inline int Filter_insert(Filter* bf, int bflog, uint64_t hash)
      hash >>= 8;
 
      size_t const fclmask = ((size_t)1 << (bflog-6)) - 1;
-     size_t const cacheLineNb = hash & fclmask;
+     size_t const cacheLineNb = (size_t)hash & fclmask;
 
      size_t const pos1 = (cacheLineNb << 6) + (slot1 >> 2);
      unsigned const shift1 = (slot1 & 3) * 2;
@@ -438,8 +432,10 @@ static inline int Filter_insert(Filter* bf, int bflog, uint64_t hash)
      static const unsigned nextValue[4] = { 1, 2, 3, 3 };
 
      bf[pos1] &= (Filter)(~(3 << shift1)); /* erase previous value */
-     bf[pos1] |= (Filter)(MAX(ex1, nextValue[existing]) << shift1);
-     bf[pos2] |= (Filter)(MAX(ex2, nextValue[existing]) << shift2);
+     unsigned const max1 = MAX(ex1, nextValue[existing]);
+     bf[pos1] |= (Filter)(max1 << shift1);
+     unsigned const max2 = MAX(ex2, nextValue[existing]);
+     bf[pos2] |= (Filter)(max2 << shift2);
 
      return addCandidates[existing];
  }
@@ -462,7 +458,7 @@ static inline int Filter_check(const Filter* bf, int bflog, uint64_t hash)
      hash >>= 8;
 
      size_t const fclmask = ((size_t)1 << (bflog-6)) - 1;
-     size_t const cacheLineNb = hash & fclmask;
+     size_t const cacheLineNb = (size_t)hash & fclmask;
 
      size_t const pos1 = (cacheLineNb << 6) + (slot1 >> 2);
      unsigned const shift1 = (slot1 & 3) * 2;
@@ -715,7 +711,7 @@ static size_t search_collisions(
 
     time_t const storeTBegin = time(NULL);
     size_t const hashByteSize = (htype == ht128) ? 16 : 8;
-    size_t const tableSize = (nbPresents+1) * hashByteSize;
+    size_t const tableSize = (size_t)((nbPresents+1) * hashByteSize);
     assert(tableSize > nbPresents);  /* check tableSize calculation overflow */
     DISPLAY(" Storing hash candidates (%i MB) \n", (int)(tableSize >> 20));
 
@@ -785,11 +781,13 @@ static size_t search_collisions(
     size_t collisions = 0;
     for (size_t n=1; n<nbCandidates; n++) {
         if (isEqual(hashCandidates, n, n-1, htype)) {
+#if defined(COL_DISPLAY_DUPLICATES)
             printf("collision: ");
             printHash(hashCandidates, n, htype);
             printf(" / ");
             printHash(hashCandidates, n-1, htype);
             printf(" \n");
+#endif
             collisions++;
     }   }
 
@@ -802,7 +800,7 @@ static size_t search_collisions(
         for (int nbHBits = 1; nbHBits < hashBits; nbHBits++) {
             uint64_t const nbSlots = (uint64_t)1 << nbHBits;
             double const expectedCollisions = estimateNbCollisions(nbCandidates, nbHBits);
-            if ( (nbSlots > nbCandidates * 100)  /* within range for meaningfull collision analysis results */
+            if ( (nbSlots > nbCandidates * 100)  /* within range for meaningful collision analysis results */
               && (expectedCollisions > 18.0) ) {
                 int const rShift = hashBits - nbHBits;
                 size_t HBits_collisions = 0;
@@ -839,6 +837,7 @@ static size_t search_collisions(
 
 
 #if defined(__MACH__) || defined(__linux__)
+
 #include <sys/resource.h>
 static size_t getProcessMemUsage(int children)
 {
@@ -847,8 +846,9 @@ static size_t getProcessMemUsage(int children)
       return (size_t)stats.ru_maxrss;
     return 0;
 }
+
 #else
-static size_t getProcessMemUsage(int ignore) { return 0; }
+static size_t getProcessMemUsage(int ignore) { (void)ignore; return 0; }
 #endif
 
 void time_collisions(searchCollisions_parameters param)
